@@ -176,23 +176,25 @@ class Scenario(Term):
         )
         return self
 
-    def _ensure_name(self, name):
+    def _ensure_name(self, name, template="Main"):
         """
         Ensure that the phases series is registered.
-        If not registered, copy the main series.
+        If not registered, copy the template phase series.
 
         Args:
             name (str): phase series name
+            template (str): name of template phase series
         """
         if name in self._series_dict.keys():
             return self._series_dict[name]
         # Phase series
-        series = copy.deepcopy(self._series_dict[self.MAIN])
-        series.clear(include_past=False)
+        if template not in self._series_dict:
+            raise KeyError(f"Template scenario {template} does not exist.")
+        series = copy.deepcopy(self._series_dict[template])
         self._series_dict[name] = series
         return series
 
-    def clear(self, name="Main", include_past=False):
+    def clear(self, name="Main", include_past=False, template="Main"):
         """
         Clear phase information.
 
@@ -203,14 +205,31 @@ class Scenario(Term):
             include_past (bool):
                 - if True, include past phases.
                 - future phase are always included
+            template (str): name of template phase series
 
         Returns:
             covsirphy.Scenario: self
         """
-        self._ensure_name(name)
+        self._ensure_name(name, template=template)
         self._series_dict[name].clear(include_past=include_past)
         return self
 
+    def _delete_series(self, name):
+        """
+        Delete a phase series.
+
+        Args:
+            name (str): name of phase series
+
+        Returns:
+            covsirphy.Scenario: self
+        """
+        if name == self.MAIN:
+            self.clear(name=name, include_past=True)
+            return self
+        self._series_dict.pop(name)
+        return self
+
     def delete(self, phases=None, name="Main"):
         """
         Delete phases.
@@ -231,14 +250,14 @@ class Scenario(Term):
         self._ensure_name(name)
         # Clear main series or delete sub phase series
         if phases is None:
-            if name == self.MAIN:
-                self.clear(name=name, include_past=True)
-                return self
-            self._series_dict.pop(name)
-            return self
+            return self._delete_series(name)
         # Delete phases
         if not isinstance(phases, list):
             raise TypeError("@phases mut be a list of phase names.")
+        phases = list(set(phases))
+        if "last" in phases:
+            self._series_dict[name].delete("last")
+            phases.remove("last")
         phases = sorted(phases, key=self.str2num, reverse=True)
         for phase in phases:
             self._series_dict[name].delete(phase)
@@ -284,7 +303,7 @@ class Scenario(Term):
         New phase name will be automatically determined.
 
         Args:
-            phases (list[str]): list of sequential phases
+            phases (list[str]): list of phases
             name (str, optional): name of phase series
             population (int): population value of the start date
             kwargs: keyword arguments to save as phase information
@@ -295,14 +314,30 @@ class Scenario(Term):
         Returns:
             covsirphy.Scenario: self
         """
-        phases = sorted(phases, key=self.str2num, reverse=True)
-        self.delete(phases=phases[:-1], name=name)
-        if population is not None:
-            unit_old = self._series_dict[name].unit(phases[-1])
-            unit = PhaseUnit(
-                unit_old.start_date, unit_old.end_date, population)
-            unit.set_ode(**kwargs)
-            self._series_dict[name].replace(phases[-1], unit)
+        series = self._ensure_name(name)
+        # Sort and check @phase is a list
+        if not isinstance(phases, list):
+            raise TypeError("@phases must be a list of phase names.")
+        phases = list(set(phases))
+        if "last" in phases:
+            last_phase = "last"
+            phases.remove("last")
+            phases = sorted(phases, key=self.str2num, reverse=False)
+        else:
+            phases = sorted(phases, key=self.str2num, reverse=False)
+            last_phase = phases[-1]
+        # Setting of the new phase
+        start_date = series.unit(phases[0]).start_date
+        end_date = series.unit(last_phase).end_date
+        population = population or series.unit(last_phase).population
+        new_unit = PhaseUnit(start_date, end_date, population)
+        new_unit.set_ode(**kwargs)
+        # Phases to keep
+        kept_units = [
+            unit for unit in series if unit < start_date or unit > end_date]
+        # Replace units
+        self._series_dict[name].replaces(
+            phase=None, new_list=kept_units + [new_unit], keep_old=False)
         return self
 
     def separate(self, date, name="Main", population=None, **kwargs):
