@@ -127,9 +127,9 @@ class TestScenario(object):
             snl.trend(show_figure=False, n_points=3)
         # Disable/enable
         length = len(snl["Main"])
-        snl.enable(phases=["0th"], name="Main")
-        assert len(snl["Main"]) == length + 1
         snl.disable(phases=["0th"], name="Main")
+        assert len(snl["Main"]) == length - 1
+        snl.enable(phases=["0th"], name="Main")
         assert len(snl["Main"]) == length
         with pytest.raises(TypeError):
             snl.enable(phases="0th", name="Main")
@@ -179,6 +179,8 @@ class TestScenario(object):
             snl.summary(columns=Term.N)
         with pytest.raises(KeyError):
             snl.summary(columns=[Term.N, "Temperature"])
+        # To markdown
+        snl.summary().to_markdown()
 
     @pytest.mark.parametrize("country", ["Greece"])
     def test_estimate(self, jhu_data, population_data, country):
